@@ -62,7 +62,7 @@ def get_methcall_report_df(baseDir, outDir):
     print(f"max_cov={max_cov}")
 
     ret_dict = defaultdict(list)
-    for tool in ToolNameList + ['NANOME']:
+    for tool in ['NANOME'] + ToolNameList:
         fnlist = glob.glob(os.path.join(baseDir, f'*_{tool}-perSite-cov1.sort.bed.gz'))
         if len(fnlist) < 1:
             print(f"Not found file in baseDir={baseDir}, pattern={f'*_{tool}-perSite-cov1.sort.bed.gz'}")
@@ -93,6 +93,7 @@ if __name__ == '__main__':
     indir_methcall = sys.argv[4]
     outdir = sys.argv[5]
     basedir = sys.argv[6]
+    version_file = sys.argv[7]
 
     ## Running information summary
     df_running_info = pd.read_csv(infn_running_info, sep='\t', )
@@ -100,23 +101,30 @@ if __name__ == '__main__':
 
     ## Basecalling report summary
     dataset_basecall = defaultdict(list)
-    with open(infn_basecall_info) as stats:
-        for line in stats:
-            linesplit = line.strip().split(':')
-            linesplit = [e.strip() for e in linesplit]
-            if line.startswith('Top 5'):
-                break
-            if len(linesplit) > 1:
-                dataset_basecall['Title'].append(linesplit[0])
-                dataset_basecall['Information'].append(linesplit[1])
-            else:
-                dataset_basecall['Title'].append(linesplit[0])
-                dataset_basecall['Information'].append("")
+    if infn_basecall_info != 'None':
+        with open(infn_basecall_info) as stats:
+            for line in stats:
+                linesplit = line.strip().split(':')
+                linesplit = [e.strip() for e in linesplit]
+                if line.startswith('Top 5'):
+                    break
+                if len(linesplit) > 1:
+                    dataset_basecall['Title'].append(linesplit[0])
+                    dataset_basecall['Information'].append(linesplit[1])
+                else:
+                    dataset_basecall['Title'].append(linesplit[0])
+                    dataset_basecall['Information'].append("")
+        df_basecall_info = pd.DataFrame.from_dict(dataset_basecall)
+    else:
+        df_basecall_info = pd.DataFrame()
 
-    df_basecall_info = pd.DataFrame.from_dict(dataset_basecall)
     print(df_basecall_info)
 
     df_methcall_info = get_methcall_report_df(indir_methcall, outdir).dropna()
+    df_version = pd.read_csv(version_file, index_col=None, sep='\t')
+
+    df_methcall_info = df_methcall_info.merge(df_version, on='Tool', how='left')
+    df_methcall_info = df_methcall_info.fillna('1.0').iloc[:, [0, 2, 1]]
     print(df_methcall_info)
 
     env = Environment(loader=FileSystemLoader(basedir))
